package com.expoware.camera;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Bitmap;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore;
import android.view.View;
import android.view.Window;
import android.widget.Button;
import android.widget.ImageView;

import java.io.File;

public class CameraActivity extends Activity
{
    private Button buttonShoot;
    private ImageView preview;
    private View.OnClickListener shootButtonClickListener;
    private String capturedImage;

    @Override
    public void onCreate(Bundle savedInstanceState)
    {
       super.onCreate(savedInstanceState);
       requestWindowFeature(Window.FEATURE_NO_TITLE);
       setContentView(R.layout.main);

       // Now that the view has been attached to the activity,
       // add widget references and event handlers
       InitializeComponents();
    }

    private void InitializeComponents()
    {
        // Ensure path exists. In particular, /images/ may not exist! If not, 0-length file created.
        capturedImage = Environment.getExternalStorageDirectory().getAbsolutePath() + "/DCIM/images/justtaken.jpg";

        // Setup button
        buttonShoot = (Button) findViewById(R.id.buttonShoot);
        shootButtonClickListener = new View.OnClickListener() {
            public void onClick(View v) {
                // Do this when the shoot button is clicked
                HandleClickForShootButton((Button) v);
            }
        };
        buttonShoot.setOnClickListener(shootButtonClickListener);

        // Setup preview
        preview = (ImageView) findViewById(R.id.preview);
    }

    private void HandleClickForShootButton(Button buttonShoot)
    {
        // Do something here like starting the camera
        //Toast t = Toast.makeText(this, "You clicked the button", Toast.LENGTH_SHORT);
        //t.show();

        // Pass a file name where to store the captured image
        Uri uri = Uri.fromFile(new File(capturedImage));
        Intent camera = new Intent(android.provider.MediaStore.ACTION_IMAGE_CAPTURE);
        camera.putExtra(MediaStore.EXTRA_OUTPUT, uri);

        startActivityForResult(camera, 0);
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent intent)
    {
        if (requestCode != 0)
            return;
        if (resultCode != -1)       // User cancelled capture
            return;

        // Display the preview of a thumbnail
        Bitmap bmp = (Bitmap) intent.getExtras().get("data");
        preview.setImageBitmap(bmp);

        // Send the original image via email
        Intent email = new Intent(android.content.Intent.ACTION_SEND);
        email.setType("image/jpeg");
        email.putExtra(android.content.Intent.EXTRA_EMAIL, new String[] {"leesposi@libero.it"});
        email.putExtra(android.content.Intent.EXTRA_SUBJECT, "JustTaken got a pic for you");
        email.putExtra(android.content.Intent.EXTRA_TEXT, "Thought it was a nice one!");
        email.putExtra(Intent.EXTRA_STREAM, Uri.parse ("file://" + capturedImage));
        startActivity(Intent.createChooser(email, "Send mail..."));
    }
}
