﻿using System;
using System.Configuration;
using System.Web;

namespace EasyCourt
{
    public class MobileRouter : IHttpModule
    {
        private const String FullSiteModeCookie = "FullSiteMode";

        #region IHttpModule Members
        public void Dispose()
        {
        }

        public void Init(HttpApplication context)
        {
            context.BeginRequest += OnBeginRequest;
        }
        #endregion

        /// <summary>
        /// Implements the main algorithm to routing mobile/desktop requests
        /// </summary>
        /// <param name="sender">Application object</param>
        /// <param name="e">Event data</param>
        private static void OnBeginRequest(Object sender, EventArgs e)
        {
            var app = sender as HttpApplication;
            if (app == null)
                throw new ArgumentNullException("sender");

            var isMobileDevice = IsRequestingBrowserMobile(app);

            // Mobile on desktop site, but FULL-SITE flag on the query string
            if (isMobileDevice && HasFullSiteFlag(app))
            {
                app.Response.AppendCookie(new HttpCookie(FullSiteModeCookie));
                return;
            }

            // Mobile on desktop site, but FULL-SITE cookie
            if (isMobileDevice && HasFullSiteCookie(app))
                return;

            // Mobile on desktop site => landing page
            if (isMobileDevice) 
                ToMobileLandingPage(app);
        }

        #region Helpers
        private static Boolean IsRequestingBrowserMobile(HttpApplication app)
        {
            return app.Context.Request.IsMobileDevice();
        }

        private static Boolean HasFullSiteFlag(HttpApplication app)
        {
            var fullSiteFlag = app.Context.Request.QueryString["m"];
            if (!String.IsNullOrEmpty(fullSiteFlag))
                return String.Equals(fullSiteFlag, "f", StringComparison.InvariantCultureIgnoreCase);

            return false;
        }

        private static Boolean HasFullSiteCookie(HttpApplication app)
        {
            var cookie = app.Context.Request.Cookies[FullSiteModeCookie];
            return cookie != null;
        }

        private static void ToMobileLandingPage(HttpApplication app)
        {
            var landingPage = ConfigurationManager.AppSettings["MobileLandingPage"];
            if (!String.IsNullOrEmpty(landingPage))
                app.Context.Response.Redirect(landingPage);
        }
        #endregion
    }
}
