//
//  MasterViewController.m
//  Guess

#import "HomeViewController.h"
#import "PlayViewController.h"
#import "ScoresViewController.h"
#import "AboutViewController.h"
#import "Constants.h"


#define kHeaderPaddingY		40.0f
#define kCellPaddingX		18.0f
#define kCellPaddingY		3.0f
#define kBarButtonPaddingX	8.0f
#define kButtonPaddingX		9.0f
#define kButtonPaddingY		20.0f


@implementation HomeViewController

#pragma mark - Alloc & Init

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
	
    if (self)
	{
		self.title = @"Guess";
    }
	
    return self;
}

#pragma mark - Methods

- (void)showAbout
{
	AboutViewController *aboutViewController = [[AboutViewController alloc] initWithNibName:@"AboutViewController" bundle:nil];
	[self.navigationController pushViewController:aboutViewController animated:YES];
}

- (void)showPlay
{
	if (_nameTextField.text && ![_nameTextField.text isEqualToString:@""])
	{
		currentAppDelegate.player = [[Player alloc] initWithName:_nameTextField.text level:_levelSegmentedControl.selectedSegmentIndex];

		UIViewController *playViewController = [[PlayViewController alloc] init];
		[self.navigationController pushViewController:playViewController animated:YES];
	}
	else
	{
		UIAlertView *alertView = [[UIAlertView alloc] initWithTitle:@"Error"
															message:@"Please insert a player name"
														   delegate:nil
												  cancelButtonTitle:@"OK"
												  otherButtonTitles:nil];
		[alertView show];
	}
}

- (void)showScores
{
	UIViewController *scoresViewController = [[ScoresViewController alloc] init];
	[self.navigationController pushViewController:scoresViewController animated:YES];
}

#pragma mark - View lifecycle

- (void)loadView
{
	[super loadView];
	
	self.view.backgroundColor = [UIColor whiteColor];
	
	// navigation bar
	UIButton *infoButton = [UIButton buttonWithType:UIButtonTypeInfoLight];
	CGRect infoButtonFrame = infoButton.frame;
	infoButtonFrame.size.width += kBarButtonPaddingX * 2.0f;
	infoButtonFrame.origin.x += kBarButtonPaddingX;
	infoButton.frame = infoButtonFrame;
	[infoButton addTarget:self action:@selector(showAbout) forControlEvents:UIControlEventTouchUpInside];
	self.navigationItem.rightBarButtonItem = [[UIBarButtonItem alloc] initWithCustomView:infoButton];
	
	// table config
	UIImageView *headerView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"logo.jpeg"]];
	CGRect headerViewFrame = headerView.frame;
	headerViewFrame.size.height += kHeaderPaddingY;
	headerView.frame = headerViewFrame;
	headerView.contentMode = UIViewContentModeCenter;
	self.tableView.tableHeaderView = headerView;
	self.tableView.bounces = NO;
	[self.tableView sizeToFit];
	
	// button images
	UIImage *redButtonImage = [[UIImage imageNamed:@"redButton"] stretchableImageWithLeftCapWidth:kButtonImageLeftCap topCapHeight:0];
	UIImage *blueButtonImage = [[UIImage imageNamed:@"blueButton"] stretchableImageWithLeftCapWidth:kButtonImageLeftCap topCapHeight:0];
	
	// buttons
	UIButton *startButton = [UIButton buttonWithType:UIButtonTypeCustom];
	[startButton setTitle:@"Start" forState:UIControlStateNormal];
	[startButton setBackgroundImage:redButtonImage forState:UIControlStateNormal];
	[startButton addTarget:self action:@selector(showPlay) forControlEvents:UIControlEventTouchUpInside];
	startButton.titleLabel.font = [UIFont boldSystemFontOfSize:kFontSize];
	startButton.frame = CGRectMake(kButtonPaddingX,
								   CGRectGetMaxY(self.tableView.frame),
								   self.view.frame.size.width - (kButtonPaddingX * 2.0f),
								   redButtonImage.size.height);
	
	UIButton *scoresButton = [UIButton buttonWithType:UIButtonTypeCustom];
	[scoresButton setTitle:@"Scores" forState:UIControlStateNormal];
	[scoresButton setBackgroundImage:blueButtonImage forState:UIControlStateNormal];
	[scoresButton addTarget:self action:@selector(showScores) forControlEvents:UIControlEventTouchUpInside];
	scoresButton.titleLabel.font = [UIFont boldSystemFontOfSize:kFontSize];
	scoresButton.frame = CGRectMake(kButtonPaddingX,
								   CGRectGetMaxY(startButton.frame) + kButtonPaddingY,
								   self.view.frame.size.width - (kButtonPaddingX * 2.0f),
								   blueButtonImage.size.height);
	
	[self.view addSubview:startButton];
	[self.view addSubview:scoresButton];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
	
	if (_nameTextField)
	{
		_nameTextField.text = @"";
	}
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

#pragma mark - UITableViewDataSource

// Customize the number of sections in the table view.
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
	return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{	
	return 2;
}

// Customize the appearance of table view cells.
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
	static NSString *nameCellID = @"nameCellID";
	static NSString *levelCellID = @"levelCellID";

	NSString *labelText = nil;
	NSString *cellID = nil;
	
	// detect cell type
	switch (indexPath.row)
	{
		case 0:
			labelText = @"Name";
			cellID = nameCellID;
			break;
			
		case 1:
			labelText = @"Level";
			cellID = levelCellID;
			break;
			
		default:
			return nil;
			break;
	}
	
	UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:cellID];
	
	// configure cell
	if (cell == nil)
	{
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:cellID];
		
		// name
		if ([cellID isEqualToString:nameCellID])
		{
			CGRect textFieldFrame = cell.frame;
			textFieldFrame.size.width = textFieldFrame.size.width * 0.7f;
			textFieldFrame.size.height -= kCellPaddingY * 2.0f;
			textFieldFrame.origin.x += (cell.frame.size.width - textFieldFrame.size.width) - kCellPaddingX;
			textFieldFrame.origin.y += kCellPaddingY;
			_nameTextField = [[UITextField alloc] initWithFrame:textFieldFrame];
			_nameTextField.autocorrectionType = UITextAutocorrectionTypeNo;
			_nameTextField.autocapitalizationType = UITextAutocapitalizationTypeNone;
			_nameTextField.delegate = self;
			_nameTextField.placeholder = labelText;
			_nameTextField.clearButtonMode = UITextFieldViewModeWhileEditing;
			_nameTextField.contentVerticalAlignment = UIControlContentVerticalAlignmentCenter;
			[cell addSubview:_nameTextField];
		}
		// level
		else if ([cellID isEqualToString:levelCellID])
		{
			CGRect segmentedControlFrame = cell.frame;
			segmentedControlFrame.size.width = segmentedControlFrame.size.width * 0.7f;
			segmentedControlFrame.size.height -= kCellPaddingY * 2.0f;
			segmentedControlFrame.origin.x += (cell.frame.size.width - segmentedControlFrame.size.width) - kCellPaddingX;
			segmentedControlFrame.origin.y += kCellPaddingY;
			_levelSegmentedControl = [[UISegmentedControl alloc] initWithItems:[NSArray arrayWithObjects:kPlayerLevelBasicString, kPlayerLevelMediumString, kPlayerLevelSuperString, nil]];
			_levelSegmentedControl.frame = segmentedControlFrame;
			_levelSegmentedControl.selectedSegmentIndex = 0;
			[cell addSubview:_levelSegmentedControl];
		}
    }
	
	cell.selectionStyle = UITableViewCellSelectionStyleNone;
	cell.accessoryType = UITableViewCellAccessoryNone;
	cell.textLabel.text = labelText;
	cell.textLabel.textAlignment = UITextAlignmentLeft;
	
    return cell;
}

#pragma mark - UITableViewDelegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
	[tableView deselectRowAtIndexPath:indexPath animated:YES];
	
	UIViewController *nextViewController = nil;
	
	switch (indexPath.section)
	{
		case 1:
			// start
			if (_nameTextField.text && ![_nameTextField.text isEqualToString:@""])
			{
				currentAppDelegate.player = [[Player alloc] initWithName:_nameTextField.text level:_levelSegmentedControl.selectedSegmentIndex];
				nextViewController = [[PlayViewController alloc] init];
			}
			else
			{
				UIAlertView *alertView = [[UIAlertView alloc] initWithTitle:@"Error"
																	message:@"Please insert a player name"
																   delegate:nil
														  cancelButtonTitle:@"OK"
														  otherButtonTitles:nil];
				[alertView show];
			}
		break;
		
		case 2:
			// scores
			nextViewController = [[ScoresViewController alloc] init];
		break;
	}
	
	if (nextViewController)
	{
		[self.navigationController pushViewController:nextViewController animated:YES];
	}
}

#pragma mark - UITextFieldDelegate

- (BOOL)textFieldShouldReturn:(UITextField *)textField
{
	[textField resignFirstResponder];
	
	return YES;
}

@end
