//
//  PlayViewController.m
//  Guess

#import "PlayViewController.h"
#import "ResultViewController.h"
#import "Constants.h"


#define kLevelLabelFormat		@"Level: %@"
#define kAttemptsLabelFormat	@"Attempts: %d"
#define kRangeLabelFormat		@"Between: %d and %d"


@implementation PlayViewController

@synthesize levelLabel = _levelLabel, attemptsLabel = _attemptsLabel, rangeLabel = _rangeLabel, numberTextField = _numberTextField;

#pragma mark - Alloc & Init

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
	
    if (self)
	{
        self.title = @"Play";
		_attempts = 0;
		_rangeMin = 0;
		_rangeMax = 0;
		_answer = 0; 
		_levelLimit = 0;
    }
	
    return self;
}

#pragma mark - Methods

- (void)updateAttempt
{	
	_attemptsLabel.text = [NSString stringWithFormat:kAttemptsLabelFormat, _attempts];
	_rangeLabel.text = [NSString stringWithFormat:kRangeLabelFormat, _rangeMin, _rangeMax];
}

- (IBAction)try:(id)sender
{
	if (![_numberTextField.text isEqualToString:@""])
	{
		NSUInteger tryValue = _numberTextField.text.integerValue;
		
		if (tryValue > _answer && tryValue <= _rangeMax)
		{
			_rangeMax = tryValue;
		}
		else if (tryValue < _answer && tryValue >= _rangeMin)
		{
			_rangeMin = tryValue;
		}
		else if (tryValue == _answer)
		{
			NSUInteger score = _levelLimit / _attempts;
			
			ResultViewController *resultViewController = [[ResultViewController alloc] initWithNibName:@"ResultViewController" bundle:nil];
			resultViewController.result = score;
			[self.navigationController pushViewController:resultViewController animated:YES];
		}
		
		_numberTextField.text = nil;
		++_attempts;
		
		[self updateAttempt];
	}
}

#pragma mark - View lifecycle

- (void)viewDidLoad
{
    [super viewDidLoad];
	
	NSString *levelString = nil;
	
	switch (currentAppDelegate.player.level)
	{
		case 0:
			levelString = kPlayerLevelBasicString;
			_rangeMax = kPlayerLevelBasicLimit;
			break;
			
		case 1:
			levelString = kPlayerLevelMediumString;
			_rangeMax = kPlayerLevelMediumLimit;
			break;
			
		case 2:
			levelString = kPlayerLevelSuperString;
			_rangeMax = kPlayerLevelSuperLimit;
			break;
	}
	
	_answer = arc4random() % (_rangeMax + 1);
	_levelLimit = _rangeMax;
	
	_levelLabel.text = [NSString stringWithFormat:kLevelLabelFormat, levelString];
	[self updateAttempt];
	
	[_numberTextField becomeFirstResponder];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

@end
