//
//  DetailViewController.m
//  Guess

#import "ResultViewController.h"
#import "ScoresViewController.h"
#import "Constants.h"


#define kScoreLabelFormat	@"Your score is: %d"


@interface ResultViewController ()
- (void)configureView;
@end


@implementation ResultViewController

@synthesize result = _result, resultLabel = _resultLabel, scoresButton = _scoresButton;

#pragma mark Alloc & Init

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
	
    if (self)
	{
		self.title = @"Result";
    }
	
    return self;
}

#pragma mark - Methods

- (IBAction)showScores:(id)sender
{
	ScoresViewController *scoresViewController = [[ScoresViewController alloc] init];
	[self.navigationController pushViewController:scoresViewController animated:YES];
}

- (void)backToHome
{
	[self.navigationController popToRootViewControllerAnimated:YES];
}

#pragma mark - Setters

- (void)setResult:(NSInteger)result
{
	// update the current player score
	_result = result;
	currentAppDelegate.player.score = _result;
	currentAppDelegate.player.scoreDate = [NSDate dateWithTimeIntervalSinceNow:0.0];
	
	// save a new array of player scores in the user defaults	
	NSUserDefaults *userDefaults = [NSUserDefaults standardUserDefaults];
	
	NSData *playersData = [userDefaults objectForKey:kPlayersArrayKey];
	NSMutableArray *playersArray = nil;
	
	if (playersData)
	{
		playersArray = [NSKeyedUnarchiver unarchiveObjectWithData:playersData];
	}
	
	if (!playersArray)
	{
		playersArray = [[NSMutableArray alloc] initWithCapacity:1];
	}

	[playersArray addObject:currentAppDelegate.player];
	playersData = [NSKeyedArchiver archivedDataWithRootObject:playersArray];
	
	[userDefaults setObject:playersData forKey:kPlayersArrayKey];
	[userDefaults synchronize];
	
	// show the current player score
	_resultLabel.text = [NSString stringWithFormat:kScoreLabelFormat, _result];
}

#pragma mark - View lifecycle

- (void)configureView
{
	// button
	UIImage *blueButtonImage = [[UIImage imageNamed:@"blueButton"] stretchableImageWithLeftCapWidth:kButtonImageLeftCap topCapHeight:0];
	[_scoresButton setTitle:@"Scores" forState:UIControlStateNormal];
	[_scoresButton setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
	[_scoresButton setBackgroundImage:blueButtonImage forState:UIControlStateNormal];
	_scoresButton.titleLabel.font = [UIFont boldSystemFontOfSize:kFontSize];
	_scoresButton.titleLabel.textColor = [UIColor whiteColor];
	CGRect scoresButtonFrame = _scoresButton.frame;
	scoresButtonFrame.size.height = blueButtonImage.size.height;
	_scoresButton.frame = scoresButtonFrame;
	
	// navigation
	self.navigationItem.hidesBackButton = YES;
	self.navigationItem.leftBarButtonItem = [[UIBarButtonItem alloc] initWithTitle:@"Home"
																			 style:UIBarButtonItemStylePlain
																			target:self
																			action:@selector(backToHome)];
	
	// show the current player score
	_resultLabel.text = [NSString stringWithFormat:kScoreLabelFormat, _result];
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
	[self configureView];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
							
@end
