package com.expoware;

import java.io.Serializable;
import java.util.Date;
import java.util.Random;

public class Game implements Serializable
{
    public GameInfo Details;
    public int Score;
    public Date GameDate;

    public int Attempts;
    public int HintsRequested = 0;
    public int Lowest = 0;
    public int Highest = 0;
    
    private int SecretNumber;

    public Game(String player, GameLevel level)
    {
        start(player, level);
    }

    private int getUpperBound()
    {
        int upperBound;
        switch(Details.Level)
        {
            case Basic:
                upperBound = 100;
                break;
            case Medium:
                upperBound = 10000;
                break;
            case Super:
                upperBound = 1000000;
                break;
            default:
                upperBound = 100;
        }
        return upperBound;
    }

    private int getLowerBound()
    {
        return 0;
    }

    private void generateSecretNumber()
    {
        Random generator = new Random();
        SecretNumber = generator.nextInt(getUpperBound());
    }
    
    private void start(String player, GameLevel level)
    {
        Details = new GameInfo(player, level);
        Score = 0;
        Attempts = 0;
        HintsRequested = 0;
        GameDate = new Date();
        Lowest = getLowerBound();
        Highest = getUpperBound();

        generateSecretNumber();
    }
    
    private int calculateScore()
    {
        return getUpperBound() / (Attempts + 2*HintsRequested);
    }

    public void quit()
    {
        start(Details.PlayerName, Details.Level);
    }

    public boolean isValidAttempt(int number)
    {
        return (number >= Lowest && number <= Highest);
    }

    public int provideHint()
    {
        HintsRequested ++;
        return Lowest + (Highest - Lowest) /2;
    }

    public boolean makeAttempt(int number)
    {
        Attempts ++;

        if (number == SecretNumber)
        {
            Score = calculateScore();
            return true;
        }

        if (number < SecretNumber)
        {
            Lowest = (number > Lowest ?number :Lowest);
        }

        if (number > SecretNumber)
        {
            Highest = (number < Highest ?number :Highest);
        }

        return false;
    }

    // For test only
    public int getSecretNumber()
    {
        return SecretNumber;
    }
}
