package com.expoware;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.*;
import android.widget.Button;
import android.widget.RadioGroup;
import android.widget.TextView;

public class GuessActivity extends Activity
{
    // References to UI widgets in main.xml
    public TextView PlayerNameEditRef;
    //public Spinner LevelSpinnerRef;
    public RadioGroup LevelRadioGroupRef;
    public Button StartButtonRef;
    public View.OnClickListener StartButtonClick;

    public void StartGame()
    {
        // Figure out selected level and player
        GameLevel selectedLevel = getSelectedLevel();
        String player =  PlayerNameEditRef.getText().toString();
        
        // Save current status for later
        PreferenceHelper.SaveGame(this, new GameInfo(player, selectedLevel));

        // Start the new activity and pass data explicitly
        Intent i = new Intent(this, GameActivity.class);
        i.putExtra(Constants.PlayerNameKey, player);
        //i.putExtra(Constants.GameLevelKey, LevelSpinnerRef.getSelectedItemPosition());
        i.putExtra(Constants.GameLevelKey, selectedLevel.ordinal());
        startActivity(i);
    }

    @Override
    public void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        setContentView(R.layout.main);

        // Initialize widgets
        GuessActivityInitializer.PrepareWidgets(this);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu)
    {
        // Invoked only once. Only use for a one-off initialization.
        return true;
    }

    @Override
    public boolean onPrepareOptionsMenu(Menu menu)
    {
        // Clear the current menu
        menu.clear();

        // Determine the menu to load based on the context
        int menuResourceId = R.menu.home;
        MenuInflater inflater = getMenuInflater();
        inflater.inflate(menuResourceId, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        // Handle item selection
        switch (item.getItemId())
        {
            case R.id.menuScores:
                ViewScores();
                return true;
            case R.id.menuAbout:
                About();
                return true;

            default:
                return super.onOptionsItemSelected(item);
        }
    }

    private void About()
    {
        Intent i = new Intent(this, AboutActivity.class);
        startActivity(i);
    }

    private void ViewScores()
    {
        Intent i = new Intent(this, ScoreListActivity.class);
        startActivity(i);
    }

    private GameLevel getSelectedLevel()
    {
        GameLevel level;
        int id = LevelRadioGroupRef.getCheckedRadioButtonId();
        switch(id)
        {
            case R.id.level_basic:
                level = GameLevel.Basic;
                break;
            case R.id.level_medium:
                level = GameLevel.Medium;
                break;
            case R.id.level_super:
                level = GameLevel.Super;
                break;
            default:
                level = GameLevel.Basic;
                break;
        }
        return level;
    }
}
