package com.expoware;

import android.content.Context;
import android.content.SharedPreferences;

public class PreferenceHelper {
    private static final String StorageName = "Guess-Info";
    private static final String StorageEntry_Player = "guess_player";
    private static final String StorageEntry_Level = "guess_level";

    private static final String StorageNameHistory = "Guess-History";

    public static GameInfo LoadGame(Context context)
    {
        SharedPreferences preferences = context.getSharedPreferences(StorageName, Context.MODE_PRIVATE);
        GameInfo savedGame = new GameInfo();
        savedGame.PlayerName = preferences.getString(StorageEntry_Player, GameInfo.DefaultPlayerName);
        GameLevel level = GameLevel.Basic;
        int index = preferences.getInt(StorageEntry_Level, -1);
        if (index >=0 && index < GameLevel.values().length)
            savedGame.Level = GameLevel.values()[index];
        return savedGame;
    }

    public static void SaveGame(Context context, GameInfo info)
    {
        SharedPreferences preferences = context.getSharedPreferences(StorageName, Context.MODE_PRIVATE);
        SharedPreferences.Editor e = preferences.edit();
        e.putString(StorageEntry_Player, info.PlayerName);
        e.putInt(StorageEntry_Level, info.Level.ordinal());
        e.commit();
    }
    
    public static void SaveHistory(Context context, GuessHistory history)
    {
        SharedPreferences preferences = context.getSharedPreferences(StorageNameHistory, Context.MODE_PRIVATE);
        SharedPreferences.Editor e = preferences.edit();
        int i=0;
        e.putInt("HistoryItemCount", history.Scores.size());
        for(ScoreInfo item : history.Scores)
        {
            String key = "score" + i;
            String value = String.format("%d$%s$%s", item.Points, item.Name, item.DateOfScore);
            e.putString(key, value);
            i++;
        }
        e.commit();
    }

    public static void ClearHistory(Context context)
    {
        SharedPreferences preferences = context.getSharedPreferences(StorageNameHistory, Context.MODE_PRIVATE);
        SharedPreferences.Editor e = preferences.edit();
        e.clear();
        e.commit();
    }

    public static GuessHistory LoadHistory(Context context)
    {
        SharedPreferences preferences = context.getSharedPreferences(StorageNameHistory, Context.MODE_PRIVATE);
        GuessHistory history = new GuessHistory();
        int historyCount = preferences.getInt("HistoryItemCount", 0);

        for(int i=0; i<historyCount; i++)
        {
            String key = "score" + i;
            String value = preferences.getString(key, "");
            String[] tokens = value.split("\\$");       // Escape to avoid it is assumed a reg-ex
            ScoreInfo si = new ScoreInfo();
            int y = tokens.length;
            si.Points = Integer.parseInt(tokens[0]);
            si.Name = tokens[1];
            si.DateOfScore = tokens[2];
            history.Scores.add(si);
        }
        return history;
    }
}
