package com.expoware;

import android.app.ListActivity;
import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.Window;
import android.widget.ArrayAdapter;

import java.util.ArrayList;
import java.util.Collections;

public class ScoreListActivity extends ListActivity
{
    @Override
    public void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        setContentView(R.layout.scoreslist);

        // Load saved scores
        LoadScores();
    }

    private void LoadScores()
    {
        ArrayList<ScoreInfo> scores = ReadScoresFromHistory();
        Bind(scores);        
    }

    private ArrayList<ScoreInfo> ReadScoresFromHistory()
    {
        GuessHistory history = PreferenceHelper.LoadHistory(this);

        // Sort
        Collections.sort(history.Scores, new ScoreComparator());
        return history.Scores;
    }
    
    private void Bind(ArrayList<ScoreInfo> scores)
    {
        ArrayAdapter<ScoreInfo> adapter = new ScoresAdapter(this, scores);
        setListAdapter(adapter);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu)
    {
        // Invoked only once. Only use for a one-off initialization.
        return true;
    }

    @Override
    public boolean onPrepareOptionsMenu(Menu menu)
    {
        // Clear the current menu
        menu.clear();

        // Determine the menu to load based on the context
        int menuResourceId = R.menu.scores;
        MenuInflater inflater = getMenuInflater();
        inflater.inflate(menuResourceId, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        // Handle item selection
        switch (item.getItemId())
        {
            case R.id.menuNewGame:
                NewGame();
                return true;
            case R.id.menuClear:
                ClearData();
                return true;
            default:
                return super.onOptionsItemSelected(item);
        }
    }

    private void NewGame()
    {
        Intent i = new Intent(this, GuessActivity.class);
        startActivity(i);
    }

    private void ClearData()
    {
        PreferenceHelper.ClearHistory(this);
        LoadScores();
    }
}
