﻿using System;
using System.Web.Mvc;
using GuessMobile.Framework.Helpers;
using GuessMobile.ViewModels.Guess;
using GuessMobile.WorkerServices.Abstractions;
using GuessMobile.WorkerServices.Guess;

namespace GuessMobile.Controllers
{
    public class GuessController : Controller
    {
        private readonly IGuessService _service;
        public GuessController() : this(new GuessService())
        {}
        public GuessController(IGuessService homeService)
        {
            _service = homeService;
        }

        public ActionResult Start()
        {
            var settings = GuessHelpers.ReadSettings();
            var model = _service.StartNewGame(settings);
            GuessHelpers.SaveState(model.State);
            return View(model);
        }

        [HttpPost]
        public ActionResult Try(Int32? number)
        {
            if (!number.HasValue)
                return Start();

            var settings = GuessHelpers.ReadSettings();
            var state = GuessHelpers.ReadState();
            var model = _service.MakeAnAttempt(settings, state, number.Value);
            GuessHelpers.SaveState(model.State);
            
            return View("Start", model);
        }

        public Int32 Hint()
        {
            var state = GuessHelpers.ReadState();
            if (state != null)
            {
                return state.LowerBound + (state.UpperBound - state.LowerBound)/2;
            }
            else 
                return new Random().Next(1, 100);
        }

        public ActionResult Stop()
        {
            var model = new GameViewModel();
            var state = GuessHelpers.ReadState();
            model.State = state;
            return View(model);
        }
    }
}
