﻿using System.Web.Mvc;
using GuessMobile.Framework.Helpers;
using GuessMobile.Framework.Logic;
using GuessMobile.ViewModels;
using GuessMobile.WorkerServices.Abstractions;
using GuessMobile.WorkerServices.Home;

namespace GuessMobile.Controllers
{
    public class HomeController : Controller
    {
        private readonly IHomeService _service;
        public HomeController() : this(new HomeService())
        {}
        public HomeController(IHomeService homeService)
        {
            _service = homeService;
        }

        /// <summary>
        /// Home page
        /// </summary>
        /// <returns></returns>
        public ActionResult Index()
        {
            var model = _service.GetHomePageInfo();
            return View(model);
        }

        /// <summary>
        /// About page
        /// </summary>
        /// <returns></returns>
        public ActionResult About()
        {
            return View(new ViewModelBase());
        }

        /// <summary>
        /// Settings page
        /// </summary>
        /// <returns></returns>
        [HttpGet]
        [ActionName("settings")]
        public ActionResult ShowSettings()
        {
            var settings = GuessHelpers.ReadSettings();
            var model = _service.GetSettingsInfo(settings);
            return View(model);
        }

        [HttpPost]
        [ActionName("settings")]
        public ActionResult ApplySettings(Settings settings, [Bind(Prefix = "levels")] Level gamelevel)
        {
            settings.GameLevel = gamelevel;
            GuessHelpers.SaveSettings(settings);
            var model = _service.GetSettingsInfo(settings);
            return View(model);
        }

        /// <summary>
        /// Best Results page
        /// </summary>
        /// <returns></returns>
        public ActionResult Results()
        {
            var model = _service.GetResultsInfo();
            return View(model);
        }
    }
}
