using System;
using GuessMobile.Framework.Logic;

namespace GuessMobile.Framework.Helpers
{
    public class GameState
    {
        private readonly Level _level;

        public GameState(Level gameLevel)
        {
            _level = gameLevel;
            var maxNumber = GetMaxNumber();
            SecretNumber = new Random().Next(1, maxNumber);
            UpperBound = maxNumber;
        }
        public Int32 LowerBound { get; set; }
        public Int32 UpperBound { get; set; }
        public Int32 NumOfAttempts { get; set; }
        public Int32 Score { get; set; }
        public Int32 SecretNumber { get; set; }
        public Boolean Success { get; set; }

        public void NewAttempt(Int32 number)
        {
            NumOfAttempts++;
            if (number == SecretNumber)
            {
                Success = true;
                Score += GetFinalBonus();
            }
            else
            {
                Score += GetScoreForAttempt();
                if (number < SecretNumber)
                    LowerBound = (LowerBound < number ? number : LowerBound);
                if (number > SecretNumber)
                    UpperBound = (UpperBound > number ? number : UpperBound);
            }
        }

        private Int32 GetMaxNumber()
        {
            switch (_level)
            {
                case Level.Medium:
                    return 10000;
                case Level.Super:
                    return 1000000;
                default:
                    return 100;
            }
        }

        private Int32 GetScoreForAttempt()
        {
            return 7 + GetRandomBonus();
        }

        private Int32 GetRandomBonus()
        {
            return new Random().Next(-3, 5);
        }

        private Int32 GetFinalBonus()
        {
            return 20;
        }
    }
}