package com.expoware;

import android.app.ListActivity;
import android.os.Bundle;
import android.os.Handler;
import android.view.View;
import android.view.Window;
import android.widget.*;

public class SimpleListActivity extends ListActivity
{
    private TextView tvLastUpdate;
    private ImageButton btnRefresh;
    private View.OnClickListener refreshClickListener;
    private Handler refreshTimer = new Handler();

    @Override
    public void onDestroy()
    {
        //refreshTimer.removeCallbacks(refreshMatchesTask);
    }

    @Override
    public void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        setContentView(R.layout.main);

        // Complete initialization
        InitializeComponents();
        HttpHelpers.Initialize(this);

        // Grab data to fill the list view
        DownloadUpdates();
    }

    protected void DownloadUpdates()
    {
        ListAdapter adapter = createAdapter();
        setListAdapter(adapter);
    }

    protected ListAdapter createAdapter()
    {
        // Create some mock data
        MatchesBundle data = StatisHelpers.GetCurrentMatches();

        // Create the adapter to populate the listview
        ListAdapter adapter = new AndroTennisAdapter(this, data.Matches);

        // Adjust the rest of the UI
        tvLastUpdate.setText(data.LastUpdate);

        return adapter;
    }

    protected void InitializeComponents()
    {
        tvLastUpdate = (TextView) findViewById(R.id.lastUpdate);
        btnRefresh = (ImageButton) findViewById(R.id.buttonRefresh);

        refreshClickListener =  new View.OnClickListener() {
            public void onClick(View v) {
                // Do this when the Refresh button is clicked
                DownloadUpdates();
            }
        };
        btnRefresh.setOnClickListener(refreshClickListener);
        refreshTimer.removeCallbacks(refreshMatchesTask);
        refreshTimer.postDelayed(refreshMatchesTask, 60000);
    }

    @Override
    protected void onListItemClick(ListView l, View v, int position, long id)
    {
        String listItem = (String) getListAdapter().getItem(position);
        Toast.makeText(this, "You selected: " + listItem, Toast.LENGTH_LONG).show();
    }

    private Runnable refreshMatchesTask = new Runnable() {
        public void run()
        {
            DownloadUpdates();
            refreshTimer.postDelayed(refreshMatchesTask, 60000);
        }
    };
}
