package com.expoware.tweet;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.text.TextWatcher;
import android.util.Log;
import android.view.*;
import android.webkit.WebView;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;
import twitter4j.Twitter;
import twitter4j.TwitterException;
import twitter4j.TwitterFactory;
import twitter4j.auth.AccessToken;
import twitter4j.auth.RequestToken;

import java.text.SimpleDateFormat;
import java.util.Calendar;

public class TweetActivity extends Activity
{
    private Button updateButton, loginButton, atButton, clearButton, hashtagButton;
    private TextView status;
    private TextView loggedUser;
    private TextView charCount;
    private View.OnClickListener updateButtonClickListener;
    private View.OnClickListener loginButtonClickListener;
    private View.OnClickListener clearButtonClickListener;
    private View.OnClickListener atButtonClickListener;
    private View.OnClickListener hashtagButtonClickListener;
    private TextWatcher textWatcher;
    private LoginInfo loginInfo;
    private Boolean isLogged = false;

    @Override
    public void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        setContentView(R.layout.main);

        // Other initialization work
        HttpHelper.Initialize(this);

        // Now that the view has been attached to the activity,
        // add widget references and event handlers
        InitializeComponents();
    }

    @Override
    protected void onStart()
    {
        // Load login information (and reflect the UI if required)
        InitializeLogin(this);

        // Enable/disable as appropriate
        EnableComponents();
        super.onStart();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu)
    {
        // Invoked only once. Do not use unless for a one-off initialization.
        return true;
    }

    @Override
    public boolean onPrepareOptionsMenu(Menu menu)
    {
        // Clear the current menu
        menu.clear();

        // Determine the menu to load based on the context
        int menuResourceId = isLogged ?R.menu.logged : R.menu.basic;
        MenuInflater inflater = getMenuInflater();
        inflater.inflate(menuResourceId, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        // Handle item selection
        switch (item.getItemId())
        {
            case R.id.menuLogout:
                Logout();
                return true;
            case R.id.menuAbout:
                About();
                return true;
            default:
                return super.onOptionsItemSelected(item);
        }
    }

    @Override
    public void onResume()
    {
        NetworkStateHelpers.RegisterReceivers();
        super.onResume();
    }

    @Override
    public void onPause()
    {
        NetworkStateHelpers.UnregisterReceivers();
        super.onPause();
    }


    private void InitializeComponents()
    {
        // Grab references
        updateButton = (Button) findViewById(R.id.buttonSave);
        loginButton = (Button) findViewById(R.id.loginButton);
        hashtagButton = (Button) findViewById(R.id.buttonHashtag);
        atButton = (Button) findViewById(R.id.buttonAt);
        clearButton = (Button) findViewById(R.id.buttonClear);
        status = (TextView) findViewById(R.id.statusText);
        loggedUser = (TextView) findViewById(R.id.loggedUser);
        charCount = (TextView) findViewById(R.id.charCount);

        // Define listeners
        updateButtonClickListener =  new View.OnClickListener() {
            public void onClick(View v) {
                // Do this when a rank button is clicked
                HandleClickForUpdateButton((Button) v);
            }
        };
        loginButtonClickListener = new View.OnClickListener() {
            public void onClick(View v) {
                // Do this when a rank button is clicked
                HandleClickForLoginButton((Button) v);
            }
        };
        clearButtonClickListener = new View.OnClickListener() {
            public void onClick(View v) {
                // Do this when a rank button is clicked
                HandleClickForClearButton((Button) v);
            }
        };
        atButtonClickListener = new View.OnClickListener() {
            public void onClick(View v) {
                // Do this when a rank button is clicked
                HandleClickForAtButton((Button) v);
            }
        };
        hashtagButtonClickListener = new View.OnClickListener() {
            public void onClick(View v) {
                // Do this when a rank button is clicked
                HandleClickForHashtagButton((Button) v);
            }
        };

        // Set up the network state receiver
        NetworkStateHelpers.SetReceiver(this, new NetworkStateReceiver(this));
        NetworkStateHelpers.RegisterReceivers();

        // Complete the setup of the UI
        updateButton.setOnClickListener(updateButtonClickListener);
        loginButton.setOnClickListener(loginButtonClickListener);
        clearButton.setOnClickListener(clearButtonClickListener);
        atButton.setOnClickListener(atButtonClickListener);
        hashtagButton.setOnClickListener(hashtagButtonClickListener);
        textWatcher = new MaxLengthTextWatcher(this, charCount);
        status.addTextChangedListener(textWatcher);
    }

    public void EnableComponents()
    {
        Boolean internet = HttpHelper.IsInternetAvailable();
        if (!internet)  {
            loginButton.setVisibility(View.GONE);
            loggedUser.setVisibility(View.VISIBLE);
            loggedUser.setText(R.string.ui_disconnected);
            updateButton.setEnabled(false);
            clearButton.setEnabled(false);
            atButton.setEnabled(false);
            hashtagButton.setEnabled(false);
            status.setEnabled(false);
        }
        else {
            loginButton.setVisibility(isLogged ? View.GONE : View.VISIBLE);
            loggedUser.setVisibility(isLogged ?View.VISIBLE :View.GONE);
            loggedUser.setText(loginInfo.ScreenName);
            updateButton.setEnabled(isLogged);
            clearButton.setEnabled(isLogged);
            atButton.setEnabled(isLogged);
            hashtagButton.setEnabled(isLogged);
            status.setEnabled(isLogged);
        }
    }

    private void HandleClickForUpdateButton(Button button)
    {
        String text = status.getText().toString();
        Calendar c = Calendar.getInstance();
        SimpleDateFormat df = new SimpleDateFormat("dd MMM, HH:mm:ss");
        String lastUpdate = df.format(c.getTime());

        String status = String.format("%s %s #webTWEETing4Android", text, lastUpdate);
        LoginInfo info = PreferenceHelper.LoadLoginInfo(this);
        MyTwitterHelpers.Update(info, status);
        Toast t = Toast.makeText(this, "Tweet uploaded ... ", Toast.LENGTH_SHORT);
        t.show();
    }

    private void HandleClickForLoginButton(Button loginButton) {
        ShowLoginScreen();
    }

    private void HandleClickForClearButton(Button button)
    {
        status.setText("");
    }

    private void HandleClickForHashtagButton(Button button)
    {
        status.append("#");
    }

    private void HandleClickForAtButton(Button button)
    {
        status.append("@");
    }

    private void InitializeLogin(Context context)
    {
        loginInfo = PreferenceHelper.LoadLoginInfo(context);
        isLogged = loginInfo.IsValid();
    }

    RequestToken requestToken;
    Twitter twitter;
    private void ShowLoginScreen()  {
        // Try authenticating with Twitter
        try {
            twitter = new TwitterFactory().getInstance();
            twitter.setOAuthConsumer(Constants.ConsumerKey, Constants.ConsumerSecret);
            requestToken = twitter.getOAuthRequestToken(Constants.CallbackUrl);
            String authUrl = requestToken.getAuthenticationURL();

            //this.startActivity(new Intent(Intent.ACTION_VIEW, Uri.parse(authUrl)));
            WebView twitterSite = new WebView(this);
            twitterSite.requestFocus(View.FOCUS_DOWN);
            twitterSite.loadUrl(authUrl);
            setContentView(twitterSite);
        } catch (TwitterException ex) {
            Toast.makeText(this, ex.getMessage(), Toast.LENGTH_LONG).show();
        }

    }

    @Override
    protected void onNewIntent(Intent intent) {
        super.onNewIntent(intent);
        Uri uri = intent.getData();
        try {
            String verifier = uri.getQueryParameter("oauth_verifier");
            if (verifier != null)
            {
                AccessToken accessToken = twitter.getOAuthAccessToken(requestToken, verifier);
                String token = accessToken.getToken();
                String secret = accessToken.getTokenSecret();
                String user = accessToken.getScreenName();

                // Save access token for further use
                LoginInfo info = new LoginInfo(user, token, secret);
                PreferenceHelper.SaveLoginInfo(this, info);
                //String buf = String.format("%s : %s", token, secret);
                //status.setText(buf);
            }
            setContentView(R.layout.main);
            InitializeLogin(this);
            EnableComponents();

        } catch (TwitterException ex) {
            Log.e("Main.onNewIntent", "" + ex.getMessage());
        }

    }

    private void Logout()
    {
        //ShowLoginScreen();
        PreferenceHelper.EmptyLoginInfo(this);
        InitializeLogin(this);
        EnableComponents();
    }

    private void About()
    {
        Intent i = new Intent(this, AboutActivity.class);
        startActivity(i);
    }
}
