using System;
using System.Web.Mvc;

// TODO: add support for a Mobile folder


namespace WurflPeek.Framework.ViewEngines
{
    /// <summary>
    /// This view engine will be able to recognize special suffix(es) in view names
    /// such as xxx.mobile.cshtml for the mobile version of a view.
    /// 
    /// RAZOR-based
    /// </summary>
    public class AmseRazorViewEngine : RazorViewEngine
    {
        private readonly ViewResolverBase _resolver;

        public AmseRazorViewEngine() : this(new DefaultWurflViewResolver())
        {
        }
        public AmseRazorViewEngine(ViewResolverBase resolver)
        {
            _resolver = resolver;
        }

        /// <summary>
        /// Resolve the name of the partial view and create it.
        /// </summary>
        /// <param name="controllerContext">context</param>
        /// <param name="partialPath">generic name of the partial view</param>
        /// <returns></returns>
        protected override IView CreatePartialView(ControllerContext controllerContext, String partialPath)
        {
            var resolvedPath = partialPath;
            if (!String.IsNullOrEmpty(partialPath))
                resolvedPath = _resolver.GetName(controllerContext.RequestContext, partialPath);
            return base.CreatePartialView(controllerContext, resolvedPath);
        }
        
        /// <summary>
        /// Resolve the name of the view and create it.
        /// </summary>
        /// <param name="controllerContext">context</param>
        /// <param name="viewPath">generic name of the view</param>
        /// <param name="masterPath">generic name of the master view</param>
        /// <returns></returns>
        protected override IView CreateView(ControllerContext controllerContext, String viewPath, String masterPath)
        {
            var resolvedViewPath = viewPath;
            var resolvedMasterPath = masterPath;

            if (!String.IsNullOrEmpty(viewPath))
                resolvedViewPath = _resolver.GetName(controllerContext.RequestContext, viewPath);
            if (!String.IsNullOrEmpty(masterPath))
                resolvedMasterPath = _resolver.GetName(controllerContext.RequestContext, masterPath);
            return base.CreateView(controllerContext, resolvedViewPath, resolvedMasterPath);
        }
    }
}