using System;
using System.IO;
using System.Web.Routing;
using WurflPeek.Framework.WurflHelpers;

namespace WurflPeek.Framework.ViewEngines
{
    /// <summary>
    /// Resolves a view applying a couple of mobile-related  modifiers: smartphone/mobile for rich/basic views.
    /// </summary>
    public class DefaultWurflViewResolver : ViewResolverBase
    {
        /// <summary>
        /// Overrides the view name according to some built-in logic.
        /// </summary>
        /// <param name="context">The current request context</param>
        /// <param name="viewName">Name of the requested view</param>
        /// <returns>A possibly modified view name</returns>
        public override String GetName(RequestContext context, String viewName)
        {
            if (!Enabled)
                return viewName; 

            // Tell WURFL to transform the name applying ad hoc mobile suffixes (i.e., index.smartphone.cshtml)
            var mobileViewName = WurflHelper.TransformViewName(context.HttpContext.Request.UserAgent, viewName);
            if (viewName.Equals(mobileViewName, StringComparison.InvariantCultureIgnoreCase))
                return viewName;

            // Check whether a file exists for the view  
            return VirtualFileExists(context, mobileViewName) ? mobileViewName : viewName;
        }
    }
}