using System;
using System.IO;
using System.Web.Mvc;
using System.Web.Routing;

namespace WurflPeek.Framework.ViewEngines
{
    public abstract class ViewResolverBase : IViewResolver
    {
        protected ViewResolverBase Decorator;
        protected ViewResolverBase()
        {
            Enabled = true;
        }

        public void AddDecorator(ViewResolverBase decorator)
        {
            Decorator = decorator;
        }

        /// <summary>
        /// Overrides the view name according to some built-in logic.
        /// </summary>
        /// <param name="context">The current request context</param>
        /// <param name="viewName">Name of the requested view</param>
        /// <returns>A possibly modified view name</returns>
        public abstract String GetName(RequestContext context, String viewName);
         
        /// <summary>
        /// Indicates if this view resolver is currently active.
        /// </summary>
        public Boolean Enabled { get; set; }

        /// <summary>
        /// Check whether a given file exists.
        /// </summary>
        /// <param name="context">The current request context</param>
        /// <param name="viewName">View name (e.g., index.mobile)</param>
        /// <returns>True if the resource exists</returns>
        protected static Boolean VirtualFileExists(RequestContext context, String viewName)
        {
            var helper = new UrlHelper(context);
            var fullVirtualPath = helper.Content(viewName);
            var physicalPath = helper.RequestContext.HttpContext.Server.MapPath(fullVirtualPath);
            return File.Exists(physicalPath);
        }
    }
}